==> qwt-6.1.5-1-armv7h.pkg.tar.xz: usr/share/doc/qwt/html/class_qwt_plot_curve.js <==
var class_qwt_plot_curve =
[
    [ "CurveAttributes", "class_qwt_plot_curve.html#a43f465d035a5125d582768944287c70c", null ],
    [ "LegendAttributes", "class_qwt_plot_curve.html#aa9b27e27ddc27466eed70485e690daa6", null ],
    [ "PaintAttributes", "class_qwt_plot_curve.html#a39ba40485087294c775a367d859b6237", null ],
    [ "CurveAttribute", "class_qwt_plot_curve.html#a38064f7de6f026a49db782c365f872c3", [
      [ "Inverted", "class_qwt_plot_curve.html#a38064f7de6f026a49db782c365f872c3af7790b4716576fd0641ec393f476bc46", null ],
      [ "Fitted", "class_qwt_plot_curve.html#a38064f7de6f026a49db782c365f872c3a583f7bc6ca4d5245fa82757f4bddea1b", null ]
    ] ],
    [ "CurveStyle", "class_qwt_plot_curve.html#a15998aa80a11ba6ba80eebabaf773f70", [
      [ "NoCurve", "class_qwt_plot_curve.html#a15998aa80a11ba6ba80eebabaf773f70a0b6dcf16619a08af39437d6b6a234c9c", null ],
      [ "Lines", "class_qwt_plot_curve.html#a15998aa80a11ba6ba80eebabaf773f70a8914d88bcd5f680e7091469fed67c9ba", null ],
      [ "Sticks", "class_qwt_plot_curve.html#a15998aa80a11ba6ba80eebabaf773f70a770b0908599507e5677b6e9ff9913f38", null ],
      [ "Steps", "class_qwt_plot_curve.html#a15998aa80a11ba6ba80eebabaf773f70a18071408a0b9bfe58378c6d81e207b2c", null ],
      [ "Dots", "class_qwt_plot_curve.html#a15998aa80a11ba6ba80eebabaf773f70ac30a3c76d19bc69fc69bed68fc154838", null ],
      [ "UserCurve", "class_qwt_plot_curve.html#a15998aa80a11ba6ba80eebabaf773f70a7d8b49e6cead1de23860e1c68d17dee3", null ]
    ] ],
    [ "LegendAttribute", "class_qwt_plot_curve.html#a6c1ac1ca99c06598c4044dd2ceeb9fd7", [
      [ "LegendNoAttribute", "class_qwt_plot_curve.html#a6c1ac1ca99c06598c4044dd2ceeb9fd7a5ca8291c000cca41c082035610b08a67", null ],
      [ "LegendShowLine", "class_qwt_plot_curve.html#a6c1ac1ca99c06598c4044dd2ceeb9fd7a7eb8387acab6a10a95219634c97c266f", null ],
      [ "LegendShowSymbol", "class_qwt_plot_curve.html#a6c1ac1ca99c06598c4044dd2ceeb9fd7a5902a8ff0c4c7f1080dd4e2bd5eb29be", null ],
      [ "LegendShowBrush", "class_qwt_plot_curve.html#a6c1ac1ca99c06598c4044dd2ceeb9fd7a20cd7f91d61c44b05c49bffd930646be", null ]
    ] ],
    [ "PaintAttribute", "class_qwt_plot_curve.html#a96db1b854c63bfbc452c943251a11b66", [
      [ "ClipPolygons", "class_qwt_plot_curve.html#a96db1b854c63bfbc452c943251a11b66a26f9aa8ae434aa94b4049b9908995abf", null ],
      [ "FilterPoints", "class_qwt_plot_curve.html#a96db1b854c63bfbc452c943251a11b66af09c1c6ec8c8198124f0e41c391f8391", null ],
      [ "MinimizeMemory", "class_qwt_plot_curve.html#a96db1b854c63bfbc452c943251a11b66a154c720d852e71b7909adf5e56a3500d", null ],
      [ "ImageBuffer", "class_qwt_plot_curve.html#a96db1b854c63bfbc452c943251a11b66a5e80434a35db4325ef8cdcb4dcb52282", null ]
    ] ],
    [ "QwtPlotCurve", "class_qwt_plot_curve.html#a57996621d9dcc44ceb942e38219bf8ff", null ],
    [ "QwtPlotCurve", "class_qwt_plot_curve.html#a3bcaa88363509f4bc1ad92bee498f203", null ],
    [ "~QwtPlotCurve", "class_qwt_plot_curve.html#aa05ec6d3883821a8e62330fbeeb85dbd", null ],
    [ "baseline", "class_qwt_plot_curve.html#af1b8d1a415addf18ee17bfeea7ffdc79", null ],
    [ "brush", "class_qwt_plot_curve.html#ad2481212584bb3c4023184c6acedfba1", null ],
    [ "closePolyline", "class_qwt_plot_curve.html#a1d0797dd72dc5958457eec4b0591c42a", null ],
    [ "closestPoint", "class_qwt_plot_curve.html#ade0ea8dbc79f314ab29bfbfb5a855ef5", null ],
    [ "curveFitter", "class_qwt_plot_curve.html#ae988a31fedc9f30c0baf34dde80c125a", null ],
    [ "drawCurve", "class_qwt_plot_curve.html#a2307196a17121dc72c2c88a0c5a46dc7", null ],
    [ "drawDots", "class_qwt_plot_curve.html#a48871008ee333f0887ff0d225645b332", null ],
    [ "drawLines", "class_qwt_plot_curve.html#a9c1ee98502ca107c9fa0edfdd0205e58", null ],
    [ "drawSeries", "class_qwt_plot_curve.html#a6d66e5b1f7a400f6c761b38133362606", null ],
    [ "drawSteps", "class_qwt_plot_curve.html#af830c84cdcfa96f33432317e79dece3e", null ],
    [ "drawSticks", "class_qwt_plot_curve.html#a5894e31d4fb8304021e3419ab8c1c999", null ],
    [ "drawSymbols", "class_qwt_plot_curve.html#a5e0a456fafffac2dfda524b44759dd9a", null ],
    [ "fillCurve", "class_qwt_plot_curve.html#a2a600e735278d8547cd5e468c9fdf5cc", null ],
    [ "init", "class_qwt_plot_curve.html#a7afecd61327d56ddc76687d119e92b5d", null ],
    [ "legendIcon", "class_qwt_plot_curve.html#a4121ed377932008cb4b1e4b6ea3f47a8", null ],
    [ "maxXValue", "class_qwt_plot_curve.html#a3d36a9679d63e4105175f6c01b8f230f", null ],
    [ "maxYValue", "class_qwt_plot_curve.html#ab294367c96791444f67c7a7f9daba49e", null ],
    [ "minXValue", "class_qwt_plot_curve.html#a34a74e192f06a2bed9905c5f43f74d56", null ],
    [ "minYValue", "class_qwt_plot_curve.html#a7f8d179560c9ea56f0f9e5db13d348e7", null ],
    [ "pen", "class_qwt_plot_curve.html#ab7506e322a6f0ce39d5d94b2b92b2155", null ],
    [ "rtti", "class_qwt_plot_curve.html#aa0db8235cdde8a5d419a7219e672d542", null ],
    [ "setBaseline", "class_qwt_plot_curve.html#adbb5da6798a60138315b18194cf1ca1e", null ],
    [ "setBrush", "class_qwt_plot_curve.html#adc52ea882ec1f994e2d2e23c7465b0c2", null ],
    [ "setCurveAttribute", "class_qwt_plot_curve.html#a6ac9243e280f96cd149102a91271a473", null ],
    [ "setCurveFitter", "class_qwt_plot_curve.html#ac15588c78d175906a30de501b4dd7957", null ],
    [ "setLegendAttribute", "class_qwt_plot_curve.html#a0b1b7816e822607eb16e6eb2fd7bfa5c", null ],
    [ "setPaintAttribute", "class_qwt_plot_curve.html#a7f9c70366415b5cb068af80be5bf3748", null ],
    [ "setPen", "class_qwt_plot_curve.html#ae00bd073a2bcf7c3c810d70af1f86750", null ],
    [ "setPen", "class_qwt_plot_curve.html#a08328abaf2c3b67e479d1e485d2d0c4d", null ],
    [ "setRawSamples", "class_qwt_plot_curve.html#afd13c94e23520dacbc37b4d0fd036a8b", null ],
    [ "setSamples", "class_qwt_plot_curve.html#aa51cd3fa00f2a046ca5a9889c5db2413", null ],
    [ "setSamples", "class_qwt_plot_curve.html#a1e6e9a417479e372197b746538fae47c", null ],
    [ "setSamples", "class_qwt_plot_curve.html#a67b24f3663484ff5e973a288c6071b2a", null ],
    [ "setSamples", "class_qwt_plot_curve.html#afa11e2336827438b8f05dfae2d1668e6", null ],
    [ "setStyle", "class_qwt_plot_curve.html#a2de41014c2b87fd459d0c438a15dd33e", null ],
    [ "setSymbol", "class_qwt_plot_curve.html#a413b1a18de12ece4dec5ae0738ecd03f", null ],
    [ "style", "class_qwt_plot_curve.html#a3a40b9e7054d35e65ecdd6956d138bc7", null ],
    [ "symbol", "class_qwt_plot_curve.html#add9a08ca3decc6a97c0a5179a23eb073", null ],
    [ "testCurveAttribute", "class_qwt_plot_curve.html#a6854cb99986d47d6e146e53c1cd164b1", null ],
    [ "testLegendAttribute", "class_qwt_plot_curve.html#a683e618515353c512e69f64ade513e06", null ],
    [ "testPaintAttribute", "class_qwt_plot_curve.html#a97c5d16689ddc8b76317522f8a3eb7e4", null ]
];

==> qwt-6.2.0-1-armv7h.pkg.tar.xz: usr/share/doc/qwt/html/class_qwt_plot_curve.js <==
var class_qwt_plot_curve =
[
    [ "CurveAttributes", "class_qwt_plot_curve.html#aef239b0fd2872333b5d8947434add425", null ],
    [ "LegendAttributes", "class_qwt_plot_curve.html#a27ba776f9d76b60aaee7e3d30aa78c2c", null ],
    [ "PaintAttributes", "class_qwt_plot_curve.html#adff5a47fcd28ea934cbdc568fe8bb85a", null ],
    [ "CurveAttribute", "class_qwt_plot_curve.html#a38064f7de6f026a49db782c365f872c3", [
      [ "Inverted", "class_qwt_plot_curve.html#a38064f7de6f026a49db782c365f872c3af7790b4716576fd0641ec393f476bc46", null ],
      [ "Fitted", "class_qwt_plot_curve.html#a38064f7de6f026a49db782c365f872c3a583f7bc6ca4d5245fa82757f4bddea1b", null ]
    ] ],
    [ "CurveStyle", "class_qwt_plot_curve.html#a15998aa80a11ba6ba80eebabaf773f70", [
      [ "NoCurve", "class_qwt_plot_curve.html#a15998aa80a11ba6ba80eebabaf773f70a0b6dcf16619a08af39437d6b6a234c9c", null ],
      [ "Lines", "class_qwt_plot_curve.html#a15998aa80a11ba6ba80eebabaf773f70a8914d88bcd5f680e7091469fed67c9ba", null ],
      [ "Sticks", "class_qwt_plot_curve.html#a15998aa80a11ba6ba80eebabaf773f70a770b0908599507e5677b6e9ff9913f38", null ],
      [ "Steps", "class_qwt_plot_curve.html#a15998aa80a11ba6ba80eebabaf773f70a18071408a0b9bfe58378c6d81e207b2c", null ],
      [ "Dots", "class_qwt_plot_curve.html#a15998aa80a11ba6ba80eebabaf773f70ac30a3c76d19bc69fc69bed68fc154838", null ],
      [ "UserCurve", "class_qwt_plot_curve.html#a15998aa80a11ba6ba80eebabaf773f70a7d8b49e6cead1de23860e1c68d17dee3", null ]
    ] ],
    [ "LegendAttribute", "class_qwt_plot_curve.html#a6c1ac1ca99c06598c4044dd2ceeb9fd7", [
      [ "LegendNoAttribute", "class_qwt_plot_curve.html#a6c1ac1ca99c06598c4044dd2ceeb9fd7a5ca8291c000cca41c082035610b08a67", null ],
      [ "LegendShowLine", "class_qwt_plot_curve.html#a6c1ac1ca99c06598c4044dd2ceeb9fd7a7eb8387acab6a10a95219634c97c266f", null ],
      [ "LegendShowSymbol", "class_qwt_plot_curve.html#a6c1ac1ca99c06598c4044dd2ceeb9fd7a5902a8ff0c4c7f1080dd4e2bd5eb29be", null ],
      [ "LegendShowBrush", "class_qwt_plot_curve.html#a6c1ac1ca99c06598c4044dd2ceeb9fd7a20cd7f91d61c44b05c49bffd930646be", null ]
    ] ],
    [ "PaintAttribute", "class_qwt_plot_curve.html#a96db1b854c63bfbc452c943251a11b66", [
      [ "ClipPolygons", "class_qwt_plot_curve.html#a96db1b854c63bfbc452c943251a11b66a26f9aa8ae434aa94b4049b9908995abf", null ],
      [ "FilterPoints", "class_qwt_plot_curve.html#a96db1b854c63bfbc452c943251a11b66af09c1c6ec8c8198124f0e41c391f8391", null ],
      [ "MinimizeMemory", "class_qwt_plot_curve.html#a96db1b854c63bfbc452c943251a11b66a154c720d852e71b7909adf5e56a3500d", null ],
      [ "ImageBuffer", "class_qwt_plot_curve.html#a96db1b854c63bfbc452c943251a11b66a5e80434a35db4325ef8cdcb4dcb52282", null ],
      [ "FilterPointsAggressive", "class_qwt_plot_curve.html#a96db1b854c63bfbc452c943251a11b66a4aed183ef24167cb6df280abf166cb7b", null ]
    ] ],
    [ "QwtPlotCurve", "class_qwt_plot_curve.html#a57996621d9dcc44ceb942e38219bf8ff", null ],
    [ "QwtPlotCurve", "class_qwt_plot_curve.html#a3bcaa88363509f4bc1ad92bee498f203", null ],
    [ "~QwtPlotCurve", "class_qwt_plot_curve.html#aa05ec6d3883821a8e62330fbeeb85dbd", null ],
    [ "baseline", "class_qwt_plot_curve.html#af1b8d1a415addf18ee17bfeea7ffdc79", null ],
    [ "brush", "class_qwt_plot_curve.html#ad2481212584bb3c4023184c6acedfba1", null ],
    [ "closePolyline", "class_qwt_plot_curve.html#a1d0797dd72dc5958457eec4b0591c42a", null ],
    [ "closestPoint", "class_qwt_plot_curve.html#a41f33574e40caee2b471615d4ac751d5", null ],
    [ "curveFitter", "class_qwt_plot_curve.html#ae988a31fedc9f30c0baf34dde80c125a", null ],
    [ "drawCurve", "class_qwt_plot_curve.html#a2307196a17121dc72c2c88a0c5a46dc7", null ],
    [ "drawDots", "class_qwt_plot_curve.html#a48871008ee333f0887ff0d225645b332", null ],
    [ "drawLines", "class_qwt_plot_curve.html#a9c1ee98502ca107c9fa0edfdd0205e58", null ],
    [ "drawSeries", "class_qwt_plot_curve.html#a0c78af2f375172ce23ed40b3d79fcef2", null ],
    [ "drawSteps", "class_qwt_plot_curve.html#af830c84cdcfa96f33432317e79dece3e", null ],
    [ "drawSticks", "class_qwt_plot_curve.html#a5894e31d4fb8304021e3419ab8c1c999", null ],
    [ "drawSymbols", "class_qwt_plot_curve.html#a5e0a456fafffac2dfda524b44759dd9a", null ],
    [ "fillCurve", "class_qwt_plot_curve.html#a2a600e735278d8547cd5e468c9fdf5cc", null ],
    [ "init", "class_qwt_plot_curve.html#a7afecd61327d56ddc76687d119e92b5d", null ],
    [ "legendAttributes", "class_qwt_plot_curve.html#a1d2d1c90dd5db249640ca77b83e1c294", null ],
    [ "legendIcon", "class_qwt_plot_curve.html#a9893a7b0e81a03a2f43e6bed5364b168", null ],
    [ "maxXValue", "class_qwt_plot_curve.html#a3d36a9679d63e4105175f6c01b8f230f", null ],
    [ "maxYValue", "class_qwt_plot_curve.html#ab294367c96791444f67c7a7f9daba49e", null ],
    [ "minXValue", "class_qwt_plot_curve.html#a34a74e192f06a2bed9905c5f43f74d56", null ],
    [ "minYValue", "class_qwt_plot_curve.html#a7f8d179560c9ea56f0f9e5db13d348e7", null ],
    [ "pen", "class_qwt_plot_curve.html#ab7506e322a6f0ce39d5d94b2b92b2155", null ],
    [ "rtti", "class_qwt_plot_curve.html#afaa5b4cfa0265b6cabaa77a18bd24fdd", null ],
    [ "setBaseline", "class_qwt_plot_curve.html#adbb5da6798a60138315b18194cf1ca1e", null ],
    [ "setBrush", "class_qwt_plot_curve.html#adc52ea882ec1f994e2d2e23c7465b0c2", null ],
    [ "setCurveAttribute", "class_qwt_plot_curve.html#a6ac9243e280f96cd149102a91271a473", null ],
    [ "setCurveFitter", "class_qwt_plot_curve.html#ac15588c78d175906a30de501b4dd7957", null ],
    [ "setLegendAttribute", "class_qwt_plot_curve.html#a0b1b7816e822607eb16e6eb2fd7bfa5c", null ],
    [ "setLegendAttributes", "class_qwt_plot_curve.html#a0d21c4aa8093baf66666d34cb1c05a58", null ],
    [ "setPaintAttribute", "class_qwt_plot_curve.html#a7f9c70366415b5cb068af80be5bf3748", null ],
    [ "setPen", "class_qwt_plot_curve.html#ae00bd073a2bcf7c3c810d70af1f86750", null ],
    [ "setPen", "class_qwt_plot_curve.html#a08328abaf2c3b67e479d1e485d2d0c4d", null ],
    [ "setRawSamples", "class_qwt_plot_curve.html#afd13c94e23520dacbc37b4d0fd036a8b", null ],
    [ "setRawSamples", "class_qwt_plot_curve.html#a9ba26e6d38cc82ba7ecf66768e36d3bf", null ],
    [ "setRawSamples", "class_qwt_plot_curve.html#adbe3f727d9d25371d768d695784b00e4", null ],
    [ "setRawSamples", "class_qwt_plot_curve.html#aaf2d63abca3d1383b4a647bca8d806d1", null ],
    [ "setSamples", "class_qwt_plot_curve.html#aa51cd3fa00f2a046ca5a9889c5db2413", null ],
    [ "setSamples", "class_qwt_plot_curve.html#aae09f7fa14708234fb902def5227073f", null ],
    [ "setSamples", "class_qwt_plot_curve.html#a8b148a9b63af53885558fc28526bcaae", null ],
    [ "setSamples", "class_qwt_plot_curve.html#a068c51f7a8c8b0b9cee3d2521b8b1a9b", null ],
    [ "setSamples", "class_qwt_plot_curve.html#a1e6e9a417479e372197b746538fae47c", null ],
    [ "setSamples", "class_qwt_plot_curve.html#addfea99426ebb30f2ba38d3243c39a1c", null ],
    [ "setSamples", "class_qwt_plot_curve.html#af0893eca2cf25d1a8c52e2df66f8ff81", null ],
    [ "setSamples", "class_qwt_plot_curve.html#ac1a31e2f5f8fc88c3ef306d9b53089d3", null ],
    [ "setSamples", "class_qwt_plot_curve.html#a67b24f3663484ff5e973a288c6071b2a", null ],
    [ "setSamples", "class_qwt_plot_curve.html#afa11e2336827438b8f05dfae2d1668e6", null ],
    [ "setStyle", "class_qwt_plot_curve.html#a2de41014c2b87fd459d0c438a15dd33e", null ],
    [ "setSymbol", "class_qwt_plot_curve.html#a413b1a18de12ece4dec5ae0738ecd03f", null ],
    [ "style", "class_qwt_plot_curve.html#a3a40b9e7054d35e65ecdd6956d138bc7", null ],
    [ "symbol", "class_qwt_plot_curve.html#add9a08ca3decc6a97c0a5179a23eb073", null ],
    [ "testCurveAttribute", "class_qwt_plot_curve.html#a6854cb99986d47d6e146e53c1cd164b1", null ],
    [ "testLegendAttribute", "class_qwt_plot_curve.html#a683e618515353c512e69f64ade513e06", null ],
    [ "testPaintAttribute", "class_qwt_plot_curve.html#a97c5d16689ddc8b76317522f8a3eb7e4", null ]
];
